@@ -25,15 +25,14 @@ __revision__ = '$Id$'
 import logging
 import os.path
 
-from sqlalchemy import *
 from sqlalchemy.exc import *
 
 import db
 import gutils
+from gettext import gettext as _
 
 log = logging.getLogger("Griffith")
 
-
 @gutils.popup_message(_('Upgrading database...'))
 def upgrade_database(self, version, config):
     """Create new db or update existing one to current format"""
@@ -116,12 +115,12 @@ def upgrade_database(self, version, config):
         db.tables.languages.insert(bind=b).execute(name=_('Turkish'))
         db.tables.tags.insert(bind=b).execute(name=_('Favourite'))
         db.tables.tags.insert(bind=b).execute(name=_('Buy me'))
-        return True # upgrade process finished
+        return True  # upgrade process finished
     #
     # next steps are only for existing databases with an outdated structure
     # not for new created databases
     #
-    if version == 1: # fix changes between v1 and v2
+    if version == 1:  # fix changes between v1 and v2
         version += 1
         log.info("Upgrading database to version %d...", version)
         b.execute("UPDATE loans SET return_date='2007-01-01' WHERE return_date='None';")
@@ -130,7 +129,7 @@ def upgrade_database(self, version, config):
         self.session.add(db_version)
         self.session.commit()
     if version == 2:    # fix changes between v2 and v3
-        #e_type = self.session.bind.engine.dialect.name
+        # e_type = self.session.bind.engine.dialect.name
         e_type = self.session.bind.name
         version += 1
         log.info("Upgrading database to version %d...", version)
@@ -143,9 +142,10 @@ def upgrade_database(self, version, config):
             db.tables.ratios.insert(bind=b).execute(name='16:9')
             db.tables.ratios.insert(bind=b).execute(name='4:3')
         except IntegrityError as e:
-            # if the following conversion of the posters takes to long and the user
-            # kills the application the database is in a undefined state which throughs that exception
-            log.warn("Cannot add values because they exist already: %s", e)
+            # if the following conversion of the posters takes too long and
+            # the user kills the application the database is in an undefined
+            # state which throws that exception
+            log.warning("Cannot add values because they exist already: %s", e)
 
         log.info('... adding new columns')
         # common SQL statements
@@ -161,19 +161,21 @@ def upgrade_database(self, version, config):
         for key, query in list(queries.items()):
             try:
                 self.session.bind.execute(query)
-            except OperationalError as e:
-                if e.message.lower().find('duplicate column name') > -1:
-                    log.warn("Cannot add '%s' column because it exists already: %s", key, e)
+            except OperationalError as ex:
+                if str(ex).lower().find('duplicate column name') > -1:
+                    log.warning("Cannot add '%s' column because it exists "
+                                "already: %s", key, ex)
                     continue
                 else:
-                    log.error("Cannot add '%s' column: %s", key, e)
+                    log.error("Cannot add '%s' column: %s", key, ex)
                     return False
-            except Exception as e:
-                log.error("Cannot add '%s' column: %s", key, e)
+            except Exception as ex:
+                log.error("Cannot add '%s' column: %s", key, ex)
                 return False
 
         log.info('... saving posters in database')
-        posters_dir = get_old_posters_location(self.data_dir, config, clean_config=True)
+        posters_dir = get_old_posters_location(self.data_dir, config,
+                                               clean_config=True)
         updated = {}
         movies_table = db.metadata.tables['movies']
         for movie in self.session.query(db.Movie.image).all():
@@ -181,20 +183,26 @@ def upgrade_database(self, version, config):
             if poster_file_name in updated:
                 continue
             if os.path.isfile(poster_file_name):
-                poster_md5 = gutils.md5sum(file(poster_file_name, 'rb'))
-                poster = self.session.query(db.Poster).filter_by(md5sum=poster_md5).first()
-                if not poster:
-                    poster = db.Poster(md5sum=poster_md5, data=file(poster_file_name, 'rb').read())
-                    self.session.add(poster)
+                with (poster_file_name, 'rb') as fp:
+                    poster_md5 = gutils.md5sum(fp)
+                    poster = self.session.query(db.Poster).filter_by(
+                        md5sum=poster_md5).first()
+                    if not poster:
+                        fp.seek(0)
+                        poster = db.Poster(md5sum=poster_md5, data=fp.read())
+                        self.session.add(poster)
 
-                update_query = movies_table.update(movies_table.c.image == movie.image, {'poster_md5': poster_md5, 'image': None}, bind=b)
+                update_query = movies_table.update(
+                    movies_table.c.image == movie.image,
+                    {'poster_md5': poster_md5, 'image': None}, bind=b)
                 # deactivating a 0.12 feature
                 save_update_onupdated = movies_table.c['updated'].onupdate
                 movies_table.c['updated'].onupdate = None
 
                 try:
-                    # yeah, we're commiting inside the loop,
-                    # it slows down the process a lot, but at least we can skip buggy posters
+                    # yeah, we're committing inside the loop,
+                    # it slows down the process a lot, but at least we can skip
+                    # buggy posters
                     update_query.execute()
                     self.session.commit()
                 except Exception as e:
@@ -204,13 +212,16 @@ def upgrade_database(self, version, config):
                     updated[poster_file_name] = True
                     try:
                         os.remove(poster_file_name)
-                    except:
-                        log.warn("cannot remove %s", poster_file_name)
+                    except Exception as ex:
+                        log.warning(f"cannot remove {poster_file_name}, "
+                                    f"{type(ex).__name__}: {ex}")
                 finally:
                     movies_table.c['updated'].onupdate = save_update_onupdated
             else:
-                log.warn("file not found: %s", movie.image)
-                update_query = movies_table.update(movies_table.c.image == movie.image, {'image': None}, bind=b)
+                log.warning("file not found: %s", movie.image)
+                update_query = movies_table.update(
+                    movies_table.c.image == movie.image, {'image': None},
+                    bind=b)
                 # deactivating a 0.12 feature
                 save_update_onupdated = movies_table.c['updated'].onupdate
                 movies_table.c['updated'].onupdate = None
@@ -221,7 +232,8 @@ def upgrade_database(self, version, config):
                 updated[poster_file_name] = True
         del updated
 
-        db_version = self.session.query(db.Configuration).filter_by(param='version').one()
+        db_version = (self.session.query(db.Configuration)
+                      .filter_by(param='version').one())
         db_version.value = str(version)
         self.session.add(db_version)
         self.session.commit()
@@ -253,7 +265,8 @@ def upgrade_database(self, version, config):
         log.info("Upgrading database to version %d...", version)
 
         log.info('... deleting old filters')
-        # new format, filters were introduced in -beta so we'll free to delete them without warning
+        # new format, filters were introduced in -beta, so we'll free to
+        # delete them without warning
         query = 'DELETE FROM filters;'
         self.session.bind.execute(query)
 
@@ -293,7 +306,7 @@ def upgrade_database(self, version, config):
 # ---------------------------------------------------
 
 
-def convert_from_old_db(config, source_file, destination_file, locations):    #{{{
+def convert_from_old_db(config, source_file, destination_file, locations):  #{{{
     """
     convert .gri database into .bd one
     """
@@ -312,22 +325,25 @@ def convert_from_old_db(config, source_file, destination_file, locations):    #{
         log.error("locations doesn't contain home path, cannot convert old database")
         return False
 
-    if open(source_file).readline()[:47] == '** This file contains an SQLite 2.1 database **':
+    with open(source_file) as fp:
+        db_file_start = fp.readline()[:47]
+    if db_file_start == '** This file contains an SQLite 2.1 database **':
         log.debug('SQLite 2.1 detected')
         try:
             import sqlite
         except ImportError:
             log.error('Old DB conversion: please install pysqlite legacy (v1.0)')
-            gutils.warning(_("Old DB conversion: please install pysqlite legacy (v1.0)"))
+            gutils.warning(
+                _("Old DB conversion: please install pysqlite legacy (v1.0)"))
             return False
     else:
         try:    # Python 2.5
             from sqlite3 import dbapi2 as sqlite
-        except ImportError: # Python < 2.5 - try to use pysqlite2
-            from pysqlite2 import dbapi2 as sqlite
+        except ImportError:  # Python < 2.5 - try to use pysqlite2
+            from pysqlite3 import dbapi2 as sqlite
 
     if os.path.isfile(destination_file):
-        # rename destination_file if it already exist
+        # rename destination_file if it already exists
         i = 1
         while True:
             if os.path.isfile("%s_%s" % (destination_file, i)):
@@ -366,7 +382,7 @@ def convert_from_old_db(config, source_file, destination_file, locations):    #{
     old_cursor.execute("UPDATE movies SET media = '7' WHERE media = 'XVID';")
     old_cursor.execute("UPDATE movies SET media = '7' WHERE media = 'WMV';")
     old_cursor.execute("UPDATE movies SET media = '9' WHERE media = 'VCD';")
-    old_cursor.execute("UPDATE movies SET media = '10' WHERE media = 'SVCD';     ")
+    old_cursor.execute("UPDATE movies SET media = '10' WHERE media = 'SVCD';")
     old_cursor.execute("UPDATE movies SET media = '11' WHERE media = 'VHS';")
     old_cursor.execute("UPDATE movies SET media = '12' WHERE media = 'BETACAM';")
     old_cursor.execute("UPDATE movies SET collection_id=0 WHERE collection_id<1")
@@ -376,8 +392,10 @@ def convert_from_old_db(config, source_file, destination_file, locations):    #{
     old_cursor.execute("UPDATE movies SET layers=NULL WHERE layers<0 OR layers='' OR layers>4")
     old_cursor.execute("UPDATE movies SET region=NULL WHERE region='' OR region=2 OR region<0 OR region>8")
     old_cursor.execute("UPDATE movies SET year=NULL WHERE year<1900 or year>2007")
-    old_cursor.execute("UPDATE movies SET rating = 0 WHERE rating NOT IN (0,1,2,3,4,5,6,7,8,9,10);") # rating>10 doesn't work with some DB
-    old_cursor.execute("UPDATE movies SET runtime = NULL WHERE runtime > 10000;") # remove strings
+    old_cursor.execute("UPDATE movies SET rating = 0 WHERE rating NOT IN (0,"
+                       "1,2,3,4,5,6,7,8,9,10);")  # rating>10 doesn't work with some DB
+    old_cursor.execute("UPDATE movies SET runtime = NULL WHERE runtime > "
+                       "10000;")  # remove strings
     old_cursor.execute("UPDATE loans SET return_date=NULL WHERE return_date=''")
     old_cursor.execute("UPDATE loans SET return_date=NULL WHERE return_date='None'")
     old_cursor.execute("DELETE FROM loans WHERE date='' OR date ISNULL")
@@ -401,7 +419,8 @@ def convert_from_old_db(config, source_file, destination_file, locations):    #{
 
     # collections
     collection_mapper = {'': None, '': None, 0: None, '0': None, -1: None, '-1': None}
-    old_cursor.execute("SELECT id, name FROM collections;") # loaned status will be set later - buggy databases :-(
+    # loaned status will be set later - buggy databases :-(
+    old_cursor.execute("SELECT id, name FROM collections;")
     for i in old_cursor.fetchall():
         o = db.Collection(name=i[1])
         try:
@@ -413,8 +432,10 @@ def convert_from_old_db(config, source_file, destination_file, locations):    #{
         collection_mapper[i[0]] = o.collection_id
 
     # volumes
-    volume_mapper = {'': None, '': None, 0: None, '0': None, -1: None, '-1': None}
-    old_cursor.execute("SELECT id, name FROM volumes;") # loaned status will be set later - buggy databases :-(
+    volume_mapper = {'': None, '': None, 0: None, '0': None, -1: None,
+                     '-1': None}
+    # loaned status will be set later - buggy databases :-(
+    old_cursor.execute("SELECT id, name FROM volumes;")
     for i in old_cursor.fetchall():
         o = db.Volume(name=i[1])
         try:
@@ -456,6 +477,8 @@ def convert_from_old_db(config, source_file, destination_file, locations):    #{
             language_mapper[i[0]] = o.lang_id
 
     # media
+    # FIXME: what may have been the intention for the two "''" keys, a key is
+    #  unique in a dictionary?
     medium_mapper = {'': None, '': None, 0: None, '0': None, -1: None, '-1': None}
     old_cursor.execute("SELECT id, name FROM media;")
     for i in old_cursor.fetchall():
@@ -520,7 +543,7 @@ def convert_from_old_db(config, source_file, destination_file, locations):    #{
         o.cast = i[17]
         o.trailer = i[18][:255]
         o.rating = digits_only(i[19])
-        #o.loaned = bool(i[20]) # updated later
+        # o.loaned = bool(i[20])  # updated later
         if int(i[21]) in medium_mapper:
             o.medium_id = medium_mapper[int(i[21])]
         o.media_num = digits_only(i[22])
@@ -557,11 +580,13 @@ def convert_from_old_db(config, source_file, destination_file, locations):    #{
     # movie lang
     old_cursor.execute("SELECT movie_id, lang_id, type FROM movie_lang WHERE movie_id IN (SELECT id FROM movies);")
     for i in old_cursor.fetchall():
-        o = new_db.session.query(db.MovieLang).filter_by(movie_id=movie_mapper[i[0]], lang_id=language_mapper[i[1]], type=i[2]).first()
+        o = new_db.session.query(db.MovieLang).filter_by(
+            movie_id=movie_mapper[i[0]], lang_id=language_mapper[i[1]],
+            movie_type=i[2]).first()
         if o is None:
             m = new_db.session.query(db.Movie).filter_by(movie_id=movie_mapper[i[0]]).one()
-            l = db.MovieLang(lang_id=language_mapper[i[1]], type=i[2])
-            m.languages.append(l)
+            lang = db.MovieLang(lang_id=language_mapper[i[1]], movie_type=i[2])
+            m.languages.append(lang)
             try:
                 new_db.session.add(m)
                 new_db.session.commit()
@@ -593,7 +618,8 @@ def convert_from_old_db(config, source_file, destination_file, locations):    #{
             elif col is not None and len(col.movies) > 0:
                 m = col.movies[0]
             else:
-                log.warn("Cannot find associated movie for this loan (%s)" % i)
+                log.warning("Cannot find associated movie for this loan (%s)"
+                            % i)
                 continue
         else:
             try:
@@ -602,35 +628,35 @@ def convert_from_old_db(config, source_file, destination_file, locations):    #{
                 log.error(e)
                 continue
 
-        l = db.Loan()
-        l.person_id = person_mapper[i[0]]
-        l.date = str(i[4])[:10]
+        lang = db.Loan()
+        lang.person_id = person_mapper[i[0]]
+        lang.date = str(i[4])[:10]
         if not_returned:
             m.loaned = True
-            l.return_date = None
+            lang.return_date = None
         else:
-            l.return_date = str(i[5])[:10]
+            lang.return_date = str(i[5])[:10]
 
         # update volume / collection status
         if int(i[2]) > 0:
-            l.volume_id = volume_mapper[i[2]]
+            lang.volume_id = volume_mapper[i[2]]
             if not_returned:
                 vol.loaned = True
                 vol.save()
         if int(i[3]) > 0:
-            l.collection_id = collection_mapper[i[3]]
+            lang.collection_id = collection_mapper[i[3]]
             if not_returned:
                 col.loaned = True
                 col.save()
-        l.save()
-        m.loans.append(l)
+        lang.save()
+        m.loans.append(lang)
         try:
             new_db.session.add(m)
             new_db.session.commit()
         except Exception as e:
             log.error(e)
             continue
-    #clear_mappers()
+    # clear_mappers()
     return new_db
 #}}}
 
