@@ -29,6 +29,7 @@ from sqlalchemy.sql.expression import Select
 import db
 import gutils
 import sql
+from gettext import gettext as _
 
 log = logging.getLogger("Griffith")
 
@@ -51,7 +52,8 @@ def on_tree_selection(tree_selection, self):
         self.widgets['popups']['print_cover'].set_sensitive(True)
     else:
         set_details(self)
-        # lets make some options unavailable when multiselction is active. for now.
+        # lets make some options unavailable when multi selection is active.
+        # for now.
         # TODO: rewrite me
         self.widgets['menu']['clone'].set_sensitive(False)
         self.widgets['menu']['make_cover'].set_sensitive(False)
@@ -64,21 +66,23 @@ def on_tree_selection(tree_selection, self):
     treeview_clicked(self)
 
 
-def foreach_treeview_selected(model, path, iter, selected):
-    selected.append(model.get_value(iter, 0))
+def foreach_treeview_selected(model, _path, iter_obj, selected):
+    selected.append(model.get_value(iter_obj, 0))
 
 
-def treeview_selection_on_event(self, treeview, iter=False):
+def treeview_selection_on_event(self, treeview, _iter=False):
     self.selected = []
-    treeview.get_selection().selected_foreach(foreach_treeview_selected, self.selected)
-    #return selected
+    treeview.get_selection().selected_foreach(
+        foreach_treeview_selected, self.selected)
+    # return selected
 
 
 def treeview_clicked(self):
     if self.initialized is False:
         return False
     if len(self.selected) == 1:
-        movie = self.db.session.query(db.Movie).filter_by(number=int(self.selected[0])).first()
+        movie = self.db.session.query(db.Movie).filter_by(
+            number=int(self.selected[0])).first()
         if self.widgets['poster_window'].props.visible:
             # poster window is visible
             filename = None
@@ -87,8 +91,8 @@ def treeview_clicked(self):
             if not filename:
                 filename = gutils.get_defaultimage_fname(self)
             self.widgets['big_poster'].set_from_file(filename)
-        #for ext in self.extensions:
-            #ext.maintree_clicked(treeselection, movie)
+        # for ext in self.extensions:
+        #     ext.maintree_clicked(treeselection, movie)
         set_details(self, movie)
     else:
         return False
@@ -108,15 +112,19 @@ def set_details(self, item=None):  # {{{
     else:
         w['number'].set_text('')
     if 'title' in item and item['title']:
-        w['title'].set_markup("<b><span size='large'>%s</span></b>" % gutils.html_encode(item['title']))
+        title_enc = gutils.html_encode(item['title'])
+        w['title'].set_markup(f"<b><span size='large'>{title_enc}</span></b>")
     else:
         w['title'].set_text('')
     if 'o_title' in item and item['o_title']:
-        w['o_title'].set_markup("<span size='medium'><i>%s</i></span>" % gutils.html_encode(item['o_title']))
+        o_title_enc = gutils.html_encode(item['o_title'])
+        w['o_title'].set_markup(
+            f"<span size='medium'><i>{o_title_enc}</i></span>")
     else:
         w['o_title'].set_text('')
     if 'director' in item and item['director']:
-        w['director'].set_markup("<i>%s</i>" % gutils.html_encode(item['director']))
+        director_enc = gutils.html_encode(item['director'])
+        w['director'].set_markup(f"<i>{director_enc}</i>")
     else:
         w['director'].set_text('')
     if 'plot' in item and item['plot']:
@@ -130,7 +138,8 @@ def set_details(self, item=None):  # {{{
     if 'resolution' in item and item['resolution']:
         if self.config.get('use_resolution_alias', True):
             w['resolution'].set_text(item['resolution'])
-        elif 'height' in item and item['height'] and 'width' in item and item['width']:
+        elif ('height' in item and item['height'] and 'width' in item
+              and item['width']):
             w['resolution'].set_text("%dx%d" % (item['width'], item['height']))
         else:  # fallback to 'resolution'
             w['resolution'].set_text(item['resolution'])
@@ -223,7 +232,7 @@ def set_details(self, item=None):  # {{{
     else:
         self._trailer_url = None
         w['go_trailer_button'].set_sensitive(False)
-    if 'seen' in item and item['seen'] == True:
+    if 'seen' in item and item['seen'] is True:
         w['seen_icon'].set_from_file(os.path.join(self.locations['images'], 'seen.png'))
     else:
         w['seen_icon'].set_from_file(os.path.join(self.locations['images'], 'unseen.png'))
@@ -250,13 +259,13 @@ def set_details(self, item=None):  # {{{
     else:
         w['vcodec'].set_text('')
     # TODO: add widgets in main and edit windows
-    #if 'ratio_id' in item:
+    # if 'ratio_id' in item:
     #    if item.ratio is not None:
     #        w['ratio'].set_markup("<i>%s</i>" % gutils.html_encode(item.ratio.name))
     #    else:
     #        w['ratio'].set_text('')
-    #else:
-    #    w['ratio'].set_text('')
+    # else:
+    #     w['ratio'].set_text('')
 
     # poster
     if 'poster_md5' in item and item['poster_md5']:
@@ -273,8 +282,9 @@ def set_details(self, item=None):  # {{{
         image_path = gutils.get_defaultimage_fname(self)
         self.widgets['add']['delete_poster'].set_sensitive(False)
         w['picture_button'].set_sensitive(False)
-    w['picture'].set_from_pixbuf(GdkPixbuf.Pixbuf.new_from_file_at_size(image_path, 100, 140))
-    # ratig
+    # w['picture'].set_from_pixbuf(GdkPixbuf.Pixbuf.new_from_file_at_size(image_path, 100, 140))
+    w['picture'].set_from_pixbuf(GdkPixbuf.Pixbuf.new_from_file_at_size(image_path, 200, 280))
+    # rating
     rimage = int(self.config.get('rating_image', 0))
     if rimage:
         prefix = ''
@@ -307,7 +317,8 @@ def set_details(self, item=None):  # {{{
             self.person_email = item.loan_details.person.email
             self.loan_date = str(item.loan_details.date)
             w['loan_info'].set_use_markup(False)
-            w['loan_info'].set_label(_("This movie has been loaned to %s on %s") % (self.person_name, self.loan_date[:10]))
+            w['loan_info'].set_label(_("This movie has been loaned to %s on %s")
+                                     % (self.person_name, self.loan_date[:10]))
     if 'loaned' in item and not item['loaned']:  # "loaned" status can be changed above, so don't use "else:" in this line
         self.widgets['popups']['loan'].set_sensitive(True)
         self.widgets['popups']['email'].set_sensitive(False)
@@ -326,7 +337,7 @@ def set_details(self, item=None):  # {{{
         for loan in item.loan_history:
             myiter = self.loans_treemodel.append(None)
             self.loans_treemodel.set_value(myiter, 0, '%s' % str(loan.date)[:10])
-            if loan.return_date and  loan.return_date != '':
+            if loan.return_date and loan.return_date != '':
                 self.loans_treemodel.set_value(myiter, 1, str(loan.return_date)[:10])
             else:
                 self.loans_treemodel.set_value(myiter, 1, "---")
@@ -343,8 +354,8 @@ def set_details(self, item=None):  # {{{
             w['volume'].set_text('')
             w['show_volume_button'].set_sensitive(False)
     else:
-            w['volume'].set_text('')
-            w['show_volume_button'].set_sensitive(False)
+        w['volume'].set_text('')
+        w['show_volume_button'].set_sensitive(False)
     if 'collection_id' in item and item['collection_id'] is not None:
         if 'collection' in item and item['collection']:
             w['collection'].set_markup("<b>%s</b>" % gutils.html_encode(item['collection'].name))
@@ -390,18 +401,19 @@ def set_details(self, item=None):  # {{{
                 w['audio_vbox'].pack_start(widget, True, True, 0)
     w['audio_vbox'].show_all()
     w['subtitle_vbox'].show_all()
-    #tags
+    # tags
     if 'tags' in item:
         tmp = ''
         for tag in item['tags']:
             tmp += "%s, " % tag.name
         tmp = tmp[:-2]  # cut last comma
         w['tags'].set_text(tmp)
-    #}}}
+    # }}}
 
 
 def populate(self, movies=None, where=None, qf=True):  # {{{
-    if self.initialized is False:  # dont try to fill movie list if Griffith is not initialized yet
+    # don't try to fill movie list if Griffith is not initialized yet
+    if self.initialized is False:
         return False
 
     if qf and movies is None or isinstance(movies, Select):  # if ".execute().fetchall()" not invoked on movies yet
@@ -470,51 +482,51 @@ def populate(self, movies=None, where=None, qf=True):  # {{{
     self.treemodel = Gtk.TreeStore(str, GdkPixbuf.Pixbuf, str, str, str, str, bool, str, str, int, str, str)
 
     # check preferences to hide or show columns
-    if self.config.get('number', True, 'mainlist') == True:
+    if self.config.get('number', True, 'mainlist') is True:
         self.number_column.set_visible(True)
     else:
         self.number_column.set_visible(False)
-    if self.config.get('otitle', True, 'mainlist') == True:
+    if self.config.get('otitle', True, 'mainlist') is True:
         self.otitle_column.set_visible(True)
     else:
         self.otitle_column.set_visible(False)
-    if self.config.get('title', True, 'mainlist') == True:
+    if self.config.get('title', True, 'mainlist') is True:
         self.title_column.set_visible(True)
     else:
         self.title_column.set_visible(False)
-    if self.config.get('director', True, 'mainlist') == True:
+    if self.config.get('director', True, 'mainlist') is True:
         self.director_column.set_visible(True)
     else:
         self.director_column.set_visible(False)
-    if self.config.get('image', True, 'mainlist') == True:
+    if self.config.get('image', True, 'mainlist') is True:
         self.image_column.set_visible(True)
     else:
         self.image_column.set_visible(False)
-    if self.config.get('genre', True, 'mainlist') == True:
+    if self.config.get('genre', True, 'mainlist') is True:
         self.genre_column.set_visible(True)
     else:
         self.genre_column.set_visible(False)
-    if self.config.get('seen', True, 'mainlist') == True:
+    if self.config.get('seen', True, 'mainlist') is True:
         self.seen_column.set_visible(True)
     else:
         self.seen_column.set_visible(False)
-    if self.config.get('year', True, 'mainlist') == True:
+    if self.config.get('year', True, 'mainlist') is True:
         self.year_column.set_visible(True)
     else:
         self.year_column.set_visible(False)
-    if self.config.get('runtime', True, 'mainlist') == True:
+    if self.config.get('runtime', True, 'mainlist') is True:
         self.runtime_column.set_visible(True)
     else:
         self.runtime_column.set_visible(False)
-    if self.config.get('rating', True, 'mainlist') == True:
+    if self.config.get('rating', True, 'mainlist') is True:
         self.rating_column.set_visible(True)
     else:
         self.rating_column.set_visible(False)
-    if self.config.get('created', True, 'mainlist') == True:
+    if self.config.get('created', True, 'mainlist') is True:
         self.created_column.set_visible(True)
     else:
         self.created_column.set_visible(False)
-    if self.config.get('updated', True, 'mainlist') == True:
+    if self.config.get('updated', True, 'mainlist') is True:
         self.updated_column.set_visible(True)
     else:
         self.updated_column.set_visible(False)
@@ -532,23 +544,23 @@ def populate(self, movies=None, where=None, qf=True):  # {{{
     if self.total:
         self.widgets['treeview'].set_cursor_on_cell(Gtk.TreePath.new_from_indices((0,)), None, None, False)
     self.count_statusbar()
-#}}}
+# }}}
 
 
 def addmovie(self, movie):  # {{{
     myiter = self.treemodel.append(None)
     setmovie(self, movie, myiter)
     return myiter
-#}}}
+# }}}
 
 
-def setmovie(self, movie, iter, treemodel=None):  # {{{
+def setmovie(self, movie, iter_obj, treemodel=None):  # {{{
     if not treemodel:
         treemodel = self.treemodel
 
-    treemodel.set_value(iter, 0, '%004d' % int(movie.number))
+    treemodel.set_value(iter_obj, 0, '%004d' % int(movie.number))
 
-    if self.config.get('image', True, section='mainlist') == True:
+    if self.config.get('image', True, section='mainlist') is True:
         filename = None
         if movie.poster_md5:
             filename = gutils.get_image_fname(movie.poster_md5, self.db, "s")
@@ -558,37 +570,40 @@ def setmovie(self, movie, iter, treemodel=None):  # {{{
         self.Image.set_from_file(filename)
         try:
             pixbuf = self.Image.get_pixbuf()
-            treemodel.set_value(iter, 1, pixbuf)
-        except:
+            treemodel.set_value(iter_obj, 1, pixbuf)
+        except Exception as exc:
             log.exception("can't load the image %s" % filename)
+            log.info(f"[E021]Caught too broad try-exception"
+                     f" {type(exc).__name__}, '{exc}'")
 
-    treemodel.set_value(iter, 2, movie.o_title)
-    treemodel.set_value(iter, 3, movie.title)
-    treemodel.set_value(iter, 4, movie.director)
-    treemodel.set_value(iter, 5, movie.genre)
-    treemodel.set_value(iter, 6, movie.seen)
+    treemodel.set_value(iter_obj, 2, movie.o_title)
+    treemodel.set_value(iter_obj, 3, movie.title)
+    treemodel.set_value(iter_obj, 4, movie.director)
+    treemodel.set_value(iter_obj, 5, movie.genre)
+    treemodel.set_value(iter_obj, 6, movie.seen)
     if movie.year is not None and (isinstance(movie.year, int) or isinstance(movie.year, int)):
-        treemodel.set_value(iter, 7, str(movie.year))
+        treemodel.set_value(iter_obj, 7, str(movie.year))
     if movie.runtime is not None and (isinstance(movie.runtime, int) or isinstance(movie.runtime, int)):
-        treemodel.set_value(iter, 8, '%003d' % movie.runtime + _(' min'))
+        treemodel.set_value(iter_obj, 8, '%003d' % movie.runtime + _(' min'))
     if movie.rating is not None and (isinstance(movie.rating, int) or isinstance(movie.rating, int)):
-        treemodel.set_value(iter, 9, movie.rating)
+        treemodel.set_value(iter_obj, 9, movie.rating)
     if movie.created:
-        treemodel.set_value(iter, 10, movie.created.strftime('%Y-%m-%d %H:%M'))
+        treemodel.set_value(iter_obj, 10, movie.created.strftime('%Y-%m-%d %H:%M'))
     if movie.updated:
-        treemodel.set_value(iter, 11, movie.updated.strftime('%Y-%m-%d %H:%M'))
-    return iter
-#}}}
+        treemodel.set_value(iter_obj, 11, movie.updated.strftime('%Y-%m-%d %H:%M'))
+    return iter_obj
+# }}}
 
 
-def select(self, iter, ensurevisible=True):  # {{{
-    if iter:
-        self.widgets['treeview'].get_selection().select_iter(iter)
+def select(self, iter_obj, ensurevisible=True):  # {{{
+    if iter_obj:
+        self.widgets['treeview'].get_selection().select_iter(iter_obj)
         if ensurevisible:
-            self.widgets['treeview'].scroll_to_cell(self.treemodel.get_path(iter))
+            self.widgets['treeview'].scroll_to_cell(
+                self.treemodel.get_path(iter_obj))
     else:
         self.widgets['treeview'].get_selection().unselect_all()
     self.treeview_clicked()
-#}}}
+# }}}
 
 # vim: fdm=marker
